﻿<?xml version="1.0" encoding="UTF-8"?>
<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">


<#import "utils.ftl" as utils>
<#-- Import common macros and functions -->
<#import "macros_common_general.ftl" as com>
<@com.initializeMainVariables />

<#import "common_module_substance_basic_information.ftl" as keySubstanceInformation>
<#import "common_module_classification_and_labelling.ftl" as keyClassifcationAndLabellingInformation>
<#import "common_module_product_basic_information.ftl" as keyProductInformation>
<#import "common_module_administrative_information.ftl" as keyAdministrativeInformation>
<#import "common_module_front_page_docbook.ftl" as fp>

<@com.initiateRelevanceGHS relevance/>

<#-- Relevance for AICIS working contexts only 'AU_ ... ' -->
<#if _subject.submissionType?has_content && _subject.submissionType?matches("AU_.*")>
	<@com.initiateRelevanceAICIS relevance/>
</#if>


  <#assign locale = "en" />
  <#assign sysDateTime = .now>

  <#assign left_header_text = ''/> 
  <#assign central_header_text = "GHS report" />
  <#assign right_header_text = ''/> 
	
	<#assign left_footer_text = sysDateTime?string["dd/MM/yyyy"] + " - IUCLID 6 " + iuclid6Version!/> 
	<#assign central_footer_text = 'GHS report' />
	<#assign right_footer_text = ''/> 

<#assign rootEntity = entity.root>
<#-- Utility list to remember tarversed entities -->
<#assign traveresedEntityKeyList = [rootEntity.documentKey]>
<#-- Utility list to remember entities yet to be traversed -->
<#assign toTravereseEntityList = []>

<#-- Get front page -->
<@fp.getFrontPage _subject _dossierHeader "GHS Classification and labelling report"/>

<#-- Maxloop sets the limit at which the component hierarchy is travered -->
<#assign maxLoop=5>

    <#-- Traverse the main entity -->
    <@traverseEntity rootEntity />

    <#list 1..maxLoop as x>           
    <#-- Remove documents that have been already traversed -->
    <#assign toTravereseEntityList = utils.removeDocumentWitKey(toTravereseEntityList, traveresedEntityKeyList) >
    <#if !(toTravereseEntityList?has_content)>
        <#-- Stop looping if there is nothing to traverse -->
        <#break>
    </#if>
        <#-- Travers each entity from the list -->
        <#list toTravereseEntityList as entityItem>
            <#assign traveresedEntityKeyList= traveresedEntityKeyList + [entityItem.documentKey]>
            <@traverseEntity entityItem />
        </#list>          
    </#list>

<#----------------------------------------------->
<#-- Macro and function definitions start here -->
<#----------------------------------------------->

<#macro traverseEntity entityDoc>
  <#if utils.isCompositeEntityDocument(entityDoc)>
    <@traverseCompositeEntity entityDoc />
  <#else>
    <@traverseSimpleEntity entityDoc />
  </#if>
</#macro>

<#macro traverseSimpleEntity entityDoc>
  <@traverseDoc entityDoc entityDoc 0 />
</#macro>

<#macro traverseCompositeEntity entityDoc>
  <#local tableOfContents=iuclid.localizeTreeFor(entityDoc.documentType, entityDoc.submissionType, entityDoc.documentKey, utils.getInheritedTemplates(entityDoc), utils.getRelatedCategories(entityDoc), utils.getRelatedMixtures(entityDoc))>
  <@traverseToc tableOfContents entityDoc 0 />
</#macro>

<#macro traverseToc sectionNode entityDocument level=0>
  <#if sectionNode?has_content>
    <#-- iterate through the section documents under this section if there are any -->
    <#if sectionNode.content?has_content>
      <#list sectionNode.content as doc>
        <#-- traverse through the document's blocks and fields aka elements -->
        <@traverseDoc doc entityDocument level+1 sectionNode />
      </#list>
    </#if>
    <#-- iterate through the child sections of the node and do a recursive call -->
    <#if sectionNode?children?has_content>
      <#list sectionNode?children as child>
        <@traverseToc child entityDocument level+1 />
      </#list>
    </#if>
  </#if>
</#macro>

<#macro traverseDoc docElementNode entityDocument level=0 sectionNode="" isDocument=true>
  <#if docElementNode?has_content>
    <#-- Annotations are only at document level -->
    <#if isDocument>
      <@printAnnotationsForDocument docElementNode entityDocument sectionNode />
    </#if>
    <#-- Check if the element node is a reference field (single or multiple) and remember referenced entities for later traversal in toTravereseEntityList -->
    <#assign toTravereseEntityList = utils.checkAndRememberReferencedEntity(docElementNode, toTravereseEntityList, traveresedEntityKeyList) />
    <#-- iterate through the child structure elements of this document element if there are any and do a recursive call -->
    <#if docElementNode?children?has_content>
      <#list docElementNode?children as child>
        <@traverseDoc child entityDocument level+1 sectionNode false/>
      </#list>
    </#if>
  </#if>
</#macro>

<#macro printAnnotationsForDocument sectionDoc entityDocument sectionNode>

  <#local sectionName = "">
  <#if sectionNode?has_content>
    <#if sectionNode.number?has_content>
      <#local sectionName = sectionNode.number + " ">
    </#if>
    <#local sectionName = sectionName + sectionNode.title>
  </#if>

  <#local sectionDocType = sectionDoc.documentType/>

  <#-- The web URL pointing to the document -->
  <#local docUrl=utils.getDocumentUrl(sectionDoc) />

  <#local entityUrl=iuclid.webUrl.entityView(entityDocument.documentKey)/>

    <#local sectionDocID = sectionDoc.documentType + "." + sectionDoc.documentSubType>
    <#if sectionDocID=="FLEXIBLE_RECORD.Ghs">
        <@tableOutput sectionDoc entityDocument sectionNode docUrl entityUrl />
    </#if>
  
</#macro>

<#macro tableOutput sectionDoc entityDocument sectionNode docUrl entityUrl>

    <chapter label="1">
    <title role="HEAD-1">Classification and labelling information for<ulink url="${entityUrl}"> <@com.text entityDocument.name/></ulink></title>
    <@com.emptyLine/>
    <para><emphasis role="bold">Document name: </emphasis><ulink url="${docUrl}"><@com.text sectionDoc.name /></ulink>         
        <para>
           IUCLID Section name: <@com.text sectionNode.title /> ${sectionNode.number}
        </para>
    </para>

    <@com.emptyLine/>
        <#if entityDocument.documentType=="SUBSTANCE">	
            <!-- basic substance identity including other names -->
            <@keySubstanceInformation.substanceIdentity entityDocument />
        <#elseif entityDocument.documentType=="MIXTURE">
            <@keyProductInformation.productInformation entityDocument />
        </#if>
        
     <@com.emptyLine/> 
        <!-- classification and labelling for common_macro_classification_and_labelling -->
        <@keyClassifcationAndLabellingInformation.classificationAndLabellingTable sectionDoc/>

    </chapter>	

</#macro>

</book>